#
# spec file for package open-iscsi
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# NOTE: do NOT make changes to this file directly in the build service,
# as this file is auto-generated from sources at:
#  https://github.com/hreinecke/open-iscsi
# So changes here will be overwritten. Instead, submit issues or pull
# requests there.
#


%define iscsi_release 876-suse
Name:           open-iscsi
Version:        2.0.876
Release:        lp150.9.9.1
Summary:        Linux Open-iSCSI Software Initiator
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
Url:            http://www.open-iscsi.com
Source:         %{name}-2.0.%{iscsi_release}.tar.bz2
Patch1:         %{name}-SUSE-latest.diff.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  db-devel < 5
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  libkmod-devel
BuildRequires:  libmount-devel
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  open-isns-devel
BuildRequires:  openssl-devel
BuildRequires:  suse-module-tools
BuildRequires:  systemd
Requires(post): coreutils
Requires:       libopeniscsiusr0_2_0 = %{version}
%{?systemd_requires}

%description
Open-iSCSI is a transport independent implementation of RFC 3720
iSCSI. It is partitioned into user and kernel parts.

The kernel portion of Open-iSCSI implements the iSCSI data path (that
is, iSCSI Read and iSCSI Write), and consists of two loadable
modules: iscsi_if.ko and iscsi_tcp.ko.

The user space part contains the entire control plane: configuration
manager, iSCSI Discovery, Login and Logout processing,
connection-level error processing, Nop-In and Nop-Out handling. It
comes with a daemon process called iscsid, and a management utility,
iscsiadm.

%package -n libopeniscsiusr0_2_0
Version:        2.0.876
Release:        lp150.9.9.1
Summary:        Userspace iSCSI API
Group:          System/Libraries
Obsoletes:      libopeniscsiusr0_1_0

%description -n libopeniscsiusr0_2_0
The iSCSI userspace API from the open-iscsi project.

%package -n iscsiuio
Version:        0.7.8.2
Release:        lp150.9.9.1
Summary:        Linux Broadcom NetXtremem II iscsi server
Group:          Productivity/Networking/Other
Requires:       logrotate

%description -n iscsiuio
This tool is to be used in conjunction with the Broadcom NetXtreme II Linux
driver (Kernel module name: "bnx2" and "bnx2x"), Broadcom CNIC driver,
and the Broadcom iSCSI driver (Kernel module name: "bnx2i").
This user space tool is used in conjunction with the following
Broadcom Network Controllers:

* bnx2:  BCM5706, BCM5708, BCM5709 devices
* bnx2x: BCM57710, BCM57711, BCM57711E, BCM57712, BCM57712E,
         BCM57800, BCM57810, BCM57840 devices

This utility will provide the ARP and DHCP functionality for the iSCSI offload.
The communication to the driver is done via Userspace I/O (Kernel module name
"uio").

%package devel
Version:        2.0.876
Release:        lp150.9.9.1
Summary:        Linux open-iscsi user-level library and include files
Group:          Development/Libraries/C and C++
Requires:       %{name}

%description devel
This development package contains the open-iscsi user-level library
include files and documentation. These are used to compile against
the libopeniscsiusr library.

%prep
%setup -q -n %{name}-2.0.%{iscsi_release}
%patch1 -p1

%build
make %{?_smp_mflags} OPTFLAGS="%{optflags} -fno-strict-aliasing -DOFFLOAD_BOOT_SUPPORTED -DUSE_KMOD -I/usr/include/kmod -DLOCK_DIR=\\\"%{_sysconfdir}/iscsi\\\"" LDFLAGS="-lkmod" user
cd iscsiuio
touch AUTHORS NEWS
autoreconf --install
%configure --sbindir=/sbin
make %{?_smp_mflags} CFLAGS="%{optflags}"

%install
make DESTDIR=%{buildroot} install_user
# install service files
make DESTDIR=%{buildroot} install_service_suse
# create rc symlinks
[ -d %{buildroot}%{_sbindir} ] || mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rciscsi
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rciscsid
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rciscsiuio
(cd %{buildroot}/etc; ln -sf iscsi/iscsid.conf iscsid.conf)
touch %{buildroot}%{_sysconfdir}/iscsi/initiatorname.iscsi
install -m 0755 usr/iscsistart %{buildroot}/sbin
%make_install -C iscsiuio
%fdupes %{buildroot}/%{_prefix}

%post
%{?regenerate_initrd_post}
if [ ! -f %{_sysconfdir}/iscsi/initiatorname.iscsi ] ; then
    /sbin/iscsi-gen-initiatorname
fi
%{service_add_post iscsid.socket iscsid.service iscsi.service}

%posttrans
%{?regenerate_initrd_posttrans}

%postun
%{service_del_postun iscsid.socket iscsid.service iscsi.service}

%pre
%{service_add_pre iscsid.socket iscsid.service iscsi.service}

%preun
%{service_del_preun iscsid.socket iscsid.service iscsi.service}

%post   -n libopeniscsiusr0_2_0 -p /sbin/ldconfig
%postun -n libopeniscsiusr0_2_0 -p /sbin/ldconfig

%post -n iscsiuio
%{service_add_post iscsiuio.socket iscsiuio.service}

%postun -n iscsiuio
%{service_del_postun iscsiuio.socket iscsiuio.service}

%pre -n iscsiuio
%{service_add_pre iscsiuio.socket iscsiuio.service}

%preun -n iscsiuio
%{service_del_preun iscsiuio.socket iscsiuio.service}

%files
%dir %{_sysconfdir}/iscsi
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/iscsi/iscsid.conf
%ghost %{_sysconfdir}/iscsi/initiatorname.iscsi
%dir %{_sysconfdir}/iscsi/ifaces
%config %{_sysconfdir}/iscsi/ifaces/iface.example
%{_sysconfdir}/iscsid.conf
%{_unitdir}/iscsid.service
%{_unitdir}/iscsid.socket
%{_unitdir}/iscsi.service
%{_libexecdir}/systemd/system-generators/ibft-rule-generator
%{_sbindir}/rciscsi
%{_sbindir}/rciscsid
/sbin/iscsid
/sbin/iscsiadm
/sbin/iscsi-iname
/sbin/iscsistart
/sbin/iscsi-gen-initiatorname
/sbin/iscsi_offload
/sbin/iscsi_discovery
/sbin/iscsi_fw_login
%doc README
%license COPYING
%{_mandir}/man8/iscsiadm.8%{ext_man}
%{_mandir}/man8/iscsid.8%{ext_man}
%{_mandir}/man8/iscsi_discovery.8%{ext_man}
%{_mandir}/man8/iscsistart.8%{ext_man}
%{_mandir}/man8/iscsi-iname.8%{ext_man}
%{_mandir}/man8/iscsi_fw_login.8%{ext_man}
%{_udevrulesdir}/50-iscsi-firmware-login.rules

%files -n libopeniscsiusr0_2_0
%{_libdir}/libopeniscsiusr.so*

%files -n iscsiuio
/sbin/iscsiuio
/sbin/brcm_iscsiuio
%{_mandir}/man8/iscsiuio.8%{ext_man}
%config %{_sysconfdir}/logrotate.d/iscsiuiolog
%{_unitdir}/iscsiuio.service
%{_unitdir}/iscsiuio.socket
%{_sbindir}/rciscsiuio

%files devel
%{_includedir}/libopeniscsiusr*.h
%{_mandir}/man3/*.3%{ext_man}

%changelog
* Thu Jan 24 2019 Lee Duncan <lduncan@suse.com>
- Fix output for iscsiadm node/iface print level P1 (bsc#1122938),
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Mon Jan  7 2019 Lee Duncan <lduncan@suse.com>
- Added two upstream qedi/iscsiuio fixes (bsc#1116711):
  * qedi: Set buf_size in case of ICMP and ARP packet.
  * qedi: Use uio BD index instead on buffer index.
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Tue Nov  6 2018 Lee Duncan <lduncan@suse.com>
- Update idbm.c files to stop i586 string overflow warnings,
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Sun Oct 28 2018 Lee Duncan <lduncan@suse.com>
- iscsiuio: Do not flush tx queue on each uio interrupt. This
  makes ping to such NICs work better (bsc#1102589), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Sun Oct 28 2018 Lee Duncan <lduncan@suse.com>
- Do not allow multiple sessions just because they were started
  in parallel (bsc#1107753), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Oct 24 2018 Lee Duncan <lduncan@suse.com>
- when iscsid started up and found stale sessions it tried
  forever to reconnect them, during which time the session
  info was printed incorrectly. Fix that printing, and add
  ability to limit reconnect retries (bsc#1088389), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Oct 24 2018 Lee Duncan <lduncan@suse.com>
- New library version needs to Obsolete the prevoius version,
  and add a note about *not* editing the SPEC file directly,
  both updating the SPEC file
* Sun Oct 21 2018 Lee Duncan <lduncan@suse.com>
- Restore space to output of "iscsiadm -m node" (bsc#1111608),
  from upstream commit, updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Sep 12 2018 Lee Duncan <lduncan@suse.com>
- Use libkmod instead of running modprobe (bsc#1106685), updating
  the spec file, and:
  * open-iscsi-SUSE-latest.diff.bz2
* Fri Aug 31 2018 Lee Duncan <lduncan@suse.com>
- iscsiuio: limit retries of dhpcv6 (bsc#1106694), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Tue Aug  7 2018 lduncan@suse.com
- Update to latest upstream, including fixes for iscsiuio
  (bsc#1100349), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Fri Jun 15 2018 lduncan@suse.com
- Updated SPEC file to use "%%license" for COPYING file
* Thu May 31 2018 lduncan@suse.com
- Fix a core dump which can occur if iscsiuio is started then
  immediately stopped (bsc#1094797), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Mon Apr 23 2018 lduncan@suse.com
- Ensure we can get qedi transport name (bsc#1090275), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Apr 18 2018 lduncan@suse.com
- Added upstream patch to allow host_id of 0 (bsc#1089687),
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Fri Apr 13 2018 lduncan@suse.com
- Added 2 upstream commits to address issue of iscsi_if.h
  stayig in sync with kernel vesion (bsc#1086344), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Thu Mar 22 2018 lduncan@suse.com
- Cleaned up complaints by gcc-8 about strings (bsc#1084640)
- Fixed rpmlint complaint about libopeniscsiusr summary
  not starting with a capital letter
- Fixed libopeniscsiusr global variable overload
- No functional changes. This updates:
  * open-iscsi-SUSE-latest.diff.bz2, and
  * open-iscsi.spec
* Wed Feb 21 2018 lduncan@suse.com
- Ensure correct dependencies: main package must depend
  on (new) libopeniscsiusr package, and devel package
  must depend on main package (updating spec file)
* Tue Feb 20 2018 lduncan@suse.com
- Fix ARP booting issue with different subnets
  (bsc#1058463), updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Wed Feb  7 2018 jengelh@inai.de
- Trim filler wording from description.
  Update old commands/RPM variables to macros.
- Implement shared library packaging guideline.
- Do not let fdupes run across partitions.
* Tue Jan 23 2018 lduncan@suse.com
- Removed the "rpm/" source directory from both the
  open-iscsi-2.0.876-suse.tar.bz2  and open-iscsi-SUSE-latest.diff.bz2
  files, since they are not needed for building and are not part
  of the upstream sources. They are still available under the
  git repository at github.com/hreinecke/open-iscsi.git. This means
  that changes to the spec file or the changes file will no longer
  require a change to the "*SUSE-latest*" file.
* Mon Jan 22 2018 lduncan@suse.com
- Update to latest upstream vesion 2.0.876, with very few
  SUSE-specific modifications, namely around things upstream
  does not care about, like SUSE-specific systemd files. Also,
  version number modified to add "-suse", as usual. See
  the Changelog file for more details on changes in this
  upstream version.
  This replaces open-iscsi-2.0.875-suse.tar.bz2 with
  open-iscsi-2.0.876-suse.tar.bz2, and resets
  open-iscsi-SUSE-latest.diff.bz2 to contain only changes
  since the 2.0.876-suse tag.
  These changes added a new libopeniscsiusr.so library, as
  well as include files under a new open-iscsi-dev package,
  if you want to link against this library.
  The SPEC file was also cleaned up using spec-cleaner.
* Thu Dec 14 2017 lduncan@suse.com
- Fix vulnerabilities found in iscsiuio by qualsys (bsc#1072312),
  updating: open-iscsi-SUSE-latest.diff.bz2
* Sat Dec  2 2017 lduncan@suse.com
- Added fixes for working with latest gcc (7.2.1),
  updating: open-iscsi-SUSE-latest.diff.bz2
* Wed Sep  6 2017 lduncan@suse.com
- Start iscsi logins before remote filesystems (bsc#1028323),
  updating:
  * open-iscsi-SUSE-latest.diff.bz2
* Sat Sep  2 2017 lduncan@suse.com
- Update to latest upstream 2.0.875, with a few SUSE-only
  modifications, replacing the 2.0.874-suse tarball with a
  2.0.875-suse version, and resetting the SUSE-latest-diff
  file to contain changes from 2.0.875-suse forward (bsc#1056689)
* Mon Aug 28 2017 lduncan@suse.com
- Add missing coreutils dependency for initrd macros (bsc#1055492)
  in SPEC file, which (as always) changes:
  * open-iscsi-SUSE-latest.diff.bz2
  +-------------------------------------------------------------------
* Thu Jul 27 2017 lduncan@suse.com
- Clear errno before calling strotull in iscsiadm
  (bsc#1029364). Note that this changes the file:
  * open-iscsi-SUSE-latest.diff.bz2
  which is changed each and every time this package is updated.
* Fri May 26 2017 lduncan@suse.com
- Added two iscsiuio upstream commits, for ipv6
  support, and general bug fixes (bsc#1040559)
* Fri Apr 28 2017 lduncan@suse.com
- Added support for qedi ping (bsc#1036238)
* Mon Apr 24 2017 lduncan@suse.com
- Fixed coredump when printing session information (bsc#1035236),
  backporting commit c8e6198dca71 from upstream open-iscsi
* Mon Apr 10 2017 lduncan@suse.com
- This is now the latest upstream open-iscsi, i.e. 2.0.874
  plus latest as of this date, together with SUSE-specific
  changes that are not yet upstream or not appropriate for
  upstream. (bsc#1032402/FATE#321911)
  Important changes in this update include:
  * qedi transport support
  * README cleanup
  * iscsiuio update
  * shutdown cleanup
  Also, the base tar file has been refactored to
  pre 2.0.874-suse as well as patches file for everything
  after that tag.
  Lastly, this update syncs this "Changes" file in Factory to and
  SLE, including SLE bug and FATE numbers, for reference.
* Fri Nov 25 2016 lduncan@suse.com
- Added two patches submitted upstream that
  make iscsi service shutdown cleaner (bsc#952437)
* Sat Oct 29 2016 lduncan@suse.com
- Added open-isns patch to remove Discovery
  Domain doubling when loading from file (bsc#897297),
  adding patch:
  * open-isns-Fix-DD-member-doubling-when-restoring-from-DB.patch
* Fri Oct 14 2016 lduncan@suse.com
- Stop manual sessions for iscsi service (bsc#989548)
* Fri May  6 2016 lduncan@suse.com
- Added patch submitted upstream that sets socket option
  to SO_LINGER (bsc#974102)
* Mon Apr 11 2016 lduncan@suse.com
- Update user-space open-iscsi tools (bsc#975217, FATE#320753),
  which included:
  + Backported changes from openSUSE:Factory branch:
  * Removing creation of open-isns RPM.
  * Allow setting host params to return EAGAIN errors.
  * Kernel include path
  * Fix iBFT target flags check.
  * fix typo
  * Fix typo in man page.
  * Use system-wide open-isns, not internal version.
  * iscsi: remove local copy of open-isns
  * iscsid: make sure actor is delated before rescheduling
  * iscsid/iscsiuio: remove uio poll
  * iscsid: fix iscsi_host_set_net_params return code
  * Syncing up utils/fwparam_ibft with upstream.
  * Syncing top-level files with upstream.
  * Fixed duplicate lines for subnet_mask and gateway
  + Update SPEC file for spliced open-isns by copying open-isns
  upstream tarball and patches from factory, since open-isns is no
  longer part of open-iscsi
* Thu Jan  7 2016 lduncan@suse.com
- Added 5 upstream patches for iscsiuio (bsc#960438):
  iscsiuio: Get the library to use based on uio sysfs name
  iscsiuio: Wait for iface to be ready before issuing the ping
  iscsiadm: let ping be tried after iface config is initialized
  iscsiuio: Add ping support through iscsiuio
  iscsid: Changes to support ping through iscsiuio
- Updated spec file copyright
- Build service git diffs now using 12-digit commit IDs
* Thu Oct  8 2015 lduncan@suse.com
- isns: exit with success when terminated with SIGTERM (bsc#948561)
* Thu Oct  8 2015 lduncan@suse.com
- isns: Adding signal managment around DB update,
  and ignore empty DB file (bsc#941791)
* Thu Oct  8 2015 lduncan@suse.com
- isns: Remove the debugging output from isnsd (bsc#949443)
* Mon Sep 28 2015 lduncan@suse.com
- added patch submitted upstream by QLogic:
  iscsiuio: Add QLogic Vendor ID to support newer NX2 HBAs
* Fri Sep  4 2015 lduncan@suse.com
- open-isns: For bsc#941944:
  - Allow setting server name with "--server"
  - Ensure we can reliably get our IP address
* Fri Sep  4 2015 lduncan@suse.com
- open-isns: For bsc#941791:
  - Set up /etc/isns/*.conf files when installing
  - Install /etc/isns/isnsadm.conf
* Thu Jul 30 2015 lduncan@suse.com
- Allow non-tcp transport for discovery daemon (bsc#939923)
* Thu Jul 23 2015 lduncan@suse.com
- Added iscsi_fw_login helper script, and new udev
  rule to call script when iBFT/iscsi boot targets
  added (bsc#869278)
* Mon Jun 29 2015 lduncan@suse.com
- Added rcsymlinks (bsc#932814)
- Cleaned up spec file for rpmlint
* Sun Jun 28 2015 lduncan@suse.com
- Updated open-iscsi to match upstream, as per bsc#936114,
  FATE#318770
  The following is a summary of changes. See
  git@github.com:hreinecke/open-iscsi.git for details of commits:
  a068906448ef Removing duplicate LDFLAGS from incorrect patch
  85ed2b4a1cb5 Prevent spinning over poll() when reconnecting to an inaccessible target
  bbffa1dd332d Fix incorrect list operation leading to out-of-order items on pend_list
  ce449cc8407f iscsiuio: Correct the handling of Multi Function mode
  e7f84d774c22 Reformat man page synopsis sections
  271b77dece32 Spelling and escaping error fixes.
  2022944815b2 Remove outdated Debian packaging code.
  d650915062d6 buildsys: respect CFLAGS and LDFLAGS from the outside
  97ae5d74d6bf buildsys: make 'make clean' idempotent
  770993b1e422 Fix small typo in iscsid.conf
  c9dcedb7b6a9 Remove duplicate newlines in log messages.
  2986f9c95f6f iscsid: don't re-read config file for every session logout
  d56f49d3f947 iscsid safe session logout
  3f59db921549 Add some more debug logging to actor.c
  75552f5519a8 iscsiuio CFLAGS fixes
  73e3e00c0e5e iscsid: fix order of setting uid/gid and drop supplementary groups
  99dfbeff1676 add discovery as a valid mode in iscsiadm.8
  688c2e9185f1 guard against NULL ptr during discovery from unexpected event
  c31ec6483815 Allow setting host params to return EAGAIN errors.
  973508df1daf fix regression in iscsi_tcp iface binding
  93c9d5ae1c86 Wake up to reap children
  24409900d9df Make running actors event-driven
  bc491ac31487 Remove actor_init and rename actor_new to actor_init
  cbcd086a2cf9 actor: Simplify actor_poll a little
  71ec348a2dfd actor: Unobfuscate ACTOR_MAX_LOOPS
  61d58fbf6de8 actor: Remove ACTOR_TICKS_10MS()
  f53eb0034618 actor: s/ACTOR_TICKS/actor_jiffies/
  dfe52b2423ff actor: simplify actor_check
  8667dcd5d628 actor: Mark actor_check static
  8037a0a30b8f Represent DHCP "origin" as an enum, not a string.
  da567155cfe9 Code cleanup: no functional changes
  6478eaac7b53 iscsiuio: Check return value from nic_queue_tx_packet
  1d07286fda46 iscsiuio: Remove set but unused variables
  382655137020 iscsiuio: Change nic_disable to return void
  7c233130687a iscsiuio: Use attribute(unused) for *icmpv6_hdr
  8e1d38215344 iscsiuio: Use attribute(unused) for variables that are unused but needed
  6ae604304b10 iscsiuio: Fix aliasing issue with IPV6_IS_ADDR_UNSPECIFIED
  63b450de0c29 iscsiuio: Resolve strict aliasing issue in iscsiuio/src/unix/nic.c
  c1e83d439f90 iscsiuio: Fix strict-aliasing warning with struct mac_address
  980c471e9f4e iscsiuio: Fix warning about non-matching types
  cb84219a4992 Fix missing header
  9d744ac8c039 Fix bad sizeof in memset
  67ff3a01e3ed Fix warning about possibly-uninitialized variable
  e5518c7a8f43 Fix build warnings for unused variables
  5d68768908e0 iscsid: don't round up when modifying padding len
  d21766d95e10 isns: Add docs for deregistering discovery domains.
  ed04ac2f9f32 iscsiadm : make iface.ipaddress optional in iface configs for transports that don't have a hard requirement on it.
  148854ae2d6e iscsiuio: Rebranding iscsiuio
  a3c40ba2ba4f iscsiadm: Initialize param_count in set_host_chap_info
  bfa2f55b0928 iscsid: Fix double close of mgmt ipc fd
  a037f5eaa9e0 iscsid: retry login for ISCSI_ERR_HOST_NOT_FOUND
  f0f3bbd25762 Fix StatSN in Open-iSCSI Stack.
  a9f4d169a95a be2iscsi: Fix MaxXmitDataLenght of the driver.
  cf1346a86489 iscsiuio: fix compilation
* Wed Apr 22 2015 lduncan@suse.com
- Double the size of the iscsiuio ARP tables,
  making it faster when switches present (bsc#922311)
* Wed Apr 22 2015 lduncan@suse.com
- Fixing ibft boot, completing commit 26020764daf70,
  which only fixed NIC context. Now boot context
  also fixed (bsc#902183)
* Mon Mar  9 2015 lduncan@suse.com
- Ported upstream commit 51c0b6ef8bc90:
  Supply strings for newly-added error numbers
* Mon Mar  9 2015 lduncan@suse.com
- Do not convert all "again" errors from transport to
  internal errors (bsc#903729)
- Update spec-file copyright date
* Fri Mar  6 2015 lduncan@suse.com
- Fixed iscsi.service start to ignore iscsiadm
  return value so that systemd knows service is
  running and can still shut it down (bsc#897565)
* Tue Nov 25 2014 lduncan@suse.com
- Fix isns server to allow legal registration sequence,
  including portal group (bsc#905670)
* Tue Oct 28 2014 lduncan@suse.com
- Added fix from Hannes to properly boot all iSCSI CNAs,
  fixing previous change (bnc#902183)
* Tue Sep 23 2014 lduncan@suse.com
- Added fix from hannes to fixup IPv6 iBFT interface
  description
* Mon Jul 28 2014 lduncan@suse.com
- Added iscsiuio spec file service macros (bnc#887143)
* Tue Jul  8 2014 hare@suse.de
- Remove unused variable 'path'
- Parse 'origin' value from iBFT
- iscsi_offload: fix detection of bnx2i (bnc#886198)
* Fri Jun  6 2014 hare@suse.de
- Valgrind fixes for iscsiuio (bnc#881692)
* Wed Jun  4 2014 lduncan@suse.com
- Added firewall service file for isns server (bnc#880305),
  adding file: open-iscsi-firewall.service
* Fri May 30 2014 hare@suse.de
- Install ibft-rule-generator (bnc#880336)
* Wed May 28 2014 hare@suse.de
- iscsi.service: do not logout from all sessions during shutdown
  (bnc#880338)
- iscsid.service: Fixup dependencies (bnc#880338)
* Fri May  2 2014 +0200 - hare@suse.de
- iscsi_offload: do not print error messages for be2iscsi
  be2iscsi HBAs display the firmware settings in
  /sys/firmware/iscsi_boot1 and only provide a subset
  of the iBFT settings (bnc#876137)
* Tue Mar 25 2014 lduncan@suse.com
- Added two not-yet-upstream patches for iscsiuio/systemd activation
  from Chris Leech (bnc#869567):
    iscsiuio-systemd-socket-activation-support.patch
    iscsiuio-systemd-unit-files.patch
  Updated spec file to handle install/package of new files.
* Fri Mar 21 2014 lduncan@suse.com
- Added an upstream patch from Mike Christie (bnc#869356):
  iscsi-tools-set-non-negotiated-params-early
* Fri Mar 14 2014 <michaelc@cs.wisc.edu>
  iscsid: Fix handling of iscsi async events.
    When iscsi targets send 32 or more iscsi async event pdus the
    initiator will run out of memory for events and this message:
    BUG: iscsid: Can not allocate memory for receive context.
    will be logged non stop. iscsid will then not be able to
    complate any more requests because it is stuck in a endless loop
    printing that message.
    This fixes the problem by having iscsid handle an event after it
    has read it in from netlink or the mgmt ipc. Previously we would
    queue all events then handle them.
* Tue Mar 11 2014 lduncan@suse.com
- Added two patches from QLogic, accepted up stream (bnc#866866):
  iscsiadm-fix-the-hostno-check-for-stats-submode-of-host-mode
  iscsiadm-fix-the-compile-time-warning
* Thu Feb 27 2014 lduncan@suse.com
- Updated systemd unit files (bnc#847953)
- Split iscsiuio out as separate package
  (part of bnc#858972)
* Thu Jan 30 2014 hare@suse.de
- Systemd integration for open-isns (FATE#316901)
* Wed Jan 29 2014 hare@suse.de
- Pulled in patches from upstream git (FATE#315963)
  * Replaced iscsiuio with upstream version
  * Switched to autotools when building iscsiuio
- Recreate SUSE-specific patches
  * Removed obsolete iscsiuio integration
  * Removed obsolete patches
  * Rediffed SUSE-specific patches
  * Removed patches
  - open-iscsi-openSUSE-12.3-first-merge.diff.bz2
  - open-iscsi-openSUSE-Factory-first-merge.diff.bz2
  - open-iscsi-openSUSE-Factory-qla4xxx-patches.diff.bz2
  - open-iscsi-sles11-sp2-latest.diff.bz2
  - open-iscsi-sles11-sp2-update.diff.bz2
  - open-iscsi-sles11-sp3-flash-update.diff.bz2
  - open-iscsi-sles11-sp3-general-updates-1.diff.bz2
  - open-iscsi-sles11-sp3-iscsiuio-update.diff.bz2
  * Added patches
  - open-iscsi-git-update.diff.bz2
  - open-iscsi-sles12-update.diff.bz2
- Build separate open-isns package (FATE#316901)
- Remove 'linux-iscsi' provides; package has last
  been used on SLES9.
* Thu Jan  9 2014 lduncan@suse.com
- Added open-iscsi-openSUSE-Factory-qla4xxx-patches.diff.bz2, with
  the following changes from QLogic (bnc#855859):
  iscsiadm.8: Updated man page for host statistics.
  README: Updated for host statistics.
  iscsi_tool: Add offload host statistics support.
  iscsiadm: Added document for description of iface attributes
  iscsi tools: Show iface params based on iface type
  iscsi tools: Let default type of iface be ipv4
  iscsi tools: iface params should be updated for node_rec as well.
  iscsi tools: Additional parameters for network settings
  iscsi tools: Ignore network parameter if not enabled/disabled
  iscsi tools: Use single function to set integer network parameters
  iscsi tools: Use single function to enable/disable network parameters
  iscsi tools: Use macro to set IPv4/IPv6 IP addresses
  iscsi_if.h: Additional parameters for network param settings
  iscsi_if.h: Remove numbers used for network parameter settings
  iscsi tools: Setup iface conf file with all iface attrs exported in sysfs
  README changes for adding support to set CHAP entry
  iscsi tools: Correctly get username_in and password_in flashnode params
  iscsiadm: Add support to set CHAP entry using host chap mode
  README changes to use long option --index instead of --flashnode_idx
  iscsiadm: Man page changes to use -x option for chap_tbl_idx
  iscsiadm: Use '-x' option instead of '-v' to specify chap_tbl_idx
  flashnode: Add support to set ISCSI_FLASHNODE_CHAP_OUT_IDX param
  iscsi tools: Print additional session info for flashnode session
  iscsiadm: Correctly check for invalid hostno and flashnode index
* Thu Dec 12 2013 lduncan@suse.com
- Fixed mkinitrd setup to not scan /etc/fstab
  (bnc#826700), changing:
  open-iscsi-openSUSE-Factory-first-merge.diff.bz2
* Mon Dec  2 2013 lduncan@suse.com
- Dropped this patch from OBS; moved to github repostiory:
  open-iscsi-2.0-873.patch
  The following patches updated to use new linux git
  requirements for longer hash values in patches, but not
  functionally changed:
  open-iscsi-openSUSE-12.3-first-merge.diff.bz2
  open-iscsi-sles11-sp2-latest.diff.bz2
  open-iscsi-sles11-sp2-update.diff.bz2
  open-iscsi-sles11-sp3-flash-update.diff.bz2
  open-iscsi-sles11-sp3-general-updates-1.diff.bz2
  open-iscsi-sles11-sp3-iscsiuio-update.diff.bz2
  This patch was also changed to absorb changes from
  open-iscsi-2.0-873.patch:
  open-iscsi-openSUSE-Factory-first-merge.diff.bz2
* Thu Nov 14 2013 crrodriguez@opensuse.org
- install the iscsistart utility which is required by dracut
* Fri Oct  4 2013 ohering@suse.de
- Remove usage of iscsiuio from mkinitrd scripts
- Add programs tags to mkinitrd scripts
  open-iscsi-2.0-873.patch
* Fri Sep 27 2013 lduncan@suse.com
- add support for systemd integration (bnc#827654)
  open-iscsi-openSUSE-Factory-first-merge.diff.bz2
* Wed Jul  3 2013 meissner@suse.com
- moved the open-iscsi branch to the SLES 11 SP3 codebase.
  Update coalesces and drops patches:
  iscsi-gen-initiatorname.sh
  open-iscsi-2.0-870-rc1-static.patch
  open-iscsi-2.0-870-rc1.tar.bz2
  open-iscsi-add-error-msg-to-log.c
  open-iscsi-add-mkinitrd-scriptlets
  open-iscsi-add-rhel5-compat
  open-iscsi-add-sles10-compat
  open-iscsi-allow-onboot-for-loginall
  open-iscsi-beta5-kernel-patch-update
  open-iscsi.changes
  open-iscsi-cxgb3i-support
  open-iscsi-error-check-in-db-lock-creation
  open-iscsi-fix-sysfs-get-value-null.patch
  open-iscsi-fixup-onboot-for-loginall
  open-iscsi-fw-crash-on-ppc
  open-iscsi-fwparam_ppc-string-overflow
  open-iscsi-header.patch
  open-iscsi-initiator-compile-warning
  open-iscsi-install-mkinitrd-scriptlets
  open-iscsi-iscsid-adjust-settings
  open-iscsi-iscsi_discovery-doc-fixes
  open-iscsi-load-ibft-before-reading-sys-firmware
  open-iscsi-login-retry-update
  open-iscsi-no-pid-file
  open-iscsi-option-no-pid-file
  open-iscsi-remove-dump-char
  open-iscsi-remove-trailing-tilde
  open-iscsi-rm-unused-variable
  open-iscsi-set-LOCK_DIR-during-compilation
  open-iscsi.spec
  open-iscsi-start-target-before-initiator
  open-iscsi-support-non-root-boot-volume.patch
  open-iscsi-suse-build-fixes
  open-iscsi-sync-modules-with-2.6.27
  open-iscsi-update-init-script
  open-iscsi-update-suse-init-scripts
- New patches:
  open-iscsi-openSUSE-12.3-first-merge.diff.bz2
  open-iscsi-sles11-sp2-latest.diff.bz2
  open-iscsi-sles11-sp2-update.diff.bz2
  open-iscsi-sles11-sp3-flash-update.diff.bz2
  open-iscsi-sles11-sp3-general-updates-1.diff.bz2
  open-iscsi-sles11-sp3-iscsiuio-update.diff.bz2
* Wed Jun  5 2013 lduncan@suse.com
- check return from nice() correctly (bnc#807936)
* Tue Jun  4 2013 lduncan@suse.com
- Branched from SLES 11 SP3
- Modified for openSUSE by removing iscsiuio references, and
  by changing service name from open-iscsi to iscsid (bnc#821695)
* Fri May 24 2013 lduncan@suse.com
- Adds support to be able to use isns discovery and
  bind the portals found to offload ifaces (bnc#820881)
* Sat May 18 2013 lduncan@suse.com
- Now handles boot-time non-root iSCSI volumes (bnc#630434)
* Thu May  9 2013 lduncan@suse.com
- Fixed iscsiadm name/value command-line parsing
  bug caused by previous update (bnc#818517)
* Fri Apr  5 2013 lduncan@suse.com
- Added iscsiadm support for user management of target adapter
  flash (bnc#810208)
* Thu Mar 14 2013 lduncan@suse.com
- Add open-iscsi-support-non-root-boot-volume.patch: handle non-
  root boot-time iscsi volumes (bnc#630434)
- Add open-iscsi-fix-sysfs-get-value-null.patch: accept "(null)"
  password as meaning no password, when using sysfs (bnc#766300)
* Mon Mar 11 2013 lduncan@suse.com
- Updated iscsiuio to latest (bnc#769125)
* Fri Sep  7 2012 lduncan@suse.com
- Added iscsiuio patches and other cleanup (bnc#751056)
* Thu Jun 21 2012 lduncan@suse.com
- Updated open-iscsi to version 2.0.873 (bnc#751056)
- Updated iscsiuio to version 0.7.4.3, to match
* Mon Feb  6 2012 hare@suse.de
- Do not install initiatorname.iscsi (bnc#742430)
- iscsi_offload: Fixup qla4xxx booting (bnc#742570)
* Fri Feb  3 2012 hare@suse.de
- Append '.suse' to version string (bnc#713975)
- iscsiadm dumps core on invalid config file (bnc#742570)
- Load iscsi_tcp kernel modules unconditionally (bnc#738040)
* Fri Dec  9 2011 hare@suse.de
- iscsiadm: Return correct error when login fails (bnc#715071)
- Add bnx2i to list of modules (bnc#718014)
- iscsi_offload: Configure interface from iBFT
- Allow modifications for iface.gateway and iface.subnet_mask
- Remove OFFLOAD_BOOT_SUPPORTED define
- iscsiadm: Allow -d flag for firmware mode
- iscsid prints invalid log message
- Start iscsiuio early in boot.open-iscsi (bnc#731216)
* Mon Nov 28 2011 hare@suse.de
- Enable offload interfaces from iscsi_offload script (bnc#730157)
* Fri Nov 25 2011 hare@suse.de
- Start iscsiuio manually again (bnc#732798)
- Remove compat code from iscsiuio
- Fixup build warnings
- Add uip_broadcast() header declaration
- Handle error when starting iscsiuio from iscsid
- Fixup definition for krecv_conn_state()
- Include iscsi-gen-initiatorname script
- Update mkinitrd scripts for iSCSI offload boot (bnc#732634)
- Added launching of iscsiuio before session sync (bnc#731216)
* Fri Nov  4 2011 hare@suse.de
- Update iscsiuio to 0.7.0.14g (bnc#726708)
- Merge with mainline:
  * Update for mixed mode on qla4xxx (bnc#727415)
  * Fix printing of unknown host values in iscsiadm
  * Fix IPv6 ibft/firmware boot
  * Remove iSNS RFC files
- Stop iscsiuio when run inside initrd (bnc#728095)
* Thu Oct 27 2011 aj@suse.de
- Rename init scripts (bnc#661401).
* Mon Oct 24 2011 hare@suse.de
- Update iscsiuio to 0.7.0.14f (bnc#687392)
- Default iscsid version to 872 for iscsiuio (bnc#687392)
* Mon Oct 10 2011 hare@suse.de
- Update iscsi_offload script (bnc#718014)
- Fixup mac address calculation
- Fixup iscsi_offload script to work on qla4xxx (bnc#722268)
* Fri Oct  7 2011 hare@suse.de
- Fix build error.
* Thu Oct  6 2011 hare@suse.de
- Merge with mainline:
  * Include qla4xxx support (bnc#722268)
  * Multiple sessions from single iface (bnc#713975)
- Fix memory leak when parsing config file
* Mon Sep 19 2011 hare@suse.de
- Update iscsiuio to 0.7.0.14d (bnc#687392)
- Fixup README (bnc#711953)
- Start iscsiuio from iscsid (bnc#718014)
* Fri Sep 16 2011 hare@suse.de
- Update iscsiuio to 0.7.0.14 (bnc#687392)
* Fri Jul 29 2011 hare@suse.de
- iscsi fails to start with bnx2i offloading (bnc#708261)
- /etc/init.d/open-iscsi fails to shutdown daemon on 'stop'
- Add 'iscsi_offload' script (FATE#311488)
- Configure all interfaces from iBFT (FATE#311345)
* Mon Jul 18 2011 hare@suse.de
- Update iscsi_uio to version 0.7.0.8 (bnc#687392)
- Add uip callbacks (bnc#687392)
- Fixup spec file to refer to iscsiuio
* Tue Jun 21 2011 hare@suse.de
- Update to version 2.0-872 (FATE#312030)
- Update brcm_iscsi_uio to version 0.7.0.4 (FATE#312028)
- Rediff patches to apply to upstream codebase
- Include scripts for automated build
* Mon Jun  6 2011 aj@suse.de
- Fix build with newer glibc.
* Wed Feb  2 2011 mweckbecker@suse.de
- Fix the following issues:
  bnc#608224: iscsi stop fails though root is not on iSCSI device-
    FIXUP
  bnc#435689: root on multipath iSCSI SLES10 SP2 host occasionally
    hangs
  bnc#455995: iSCSI connections should not get closed if unmount
    fails
* Mon Jan 31 2011 mweckbecker@suse.de
- open-iscsi-start-multipath-before-iscsi: updated to apply w/
  fuzz=0
* Fri Jul 30 2010 hare@suse.de
- Parse iface entry correctly in init script
- Tear down block device stack on 'open-iscsi stop' (bnc#608224)
* Mon Jun 28 2010 hare@suse.de
- open-iscsi stop returns 'failed' for root on iSCSI (bnc#608224)
- Extract correct session information for firmware sessions
  (bnc#617883)
- Start multipathd before open-iscsi (bnc#603382)
* Mon Apr 26 2010 ro@suse.de
- also enter boot.multipath in Should-Stop
* Mon Apr 26 2010 hare@suse.de
- Start boot.multipath prior to boot.open-iscsi (bnc#595629)
* Tue Apr 20 2010 hare@suse.de
- Do send SIGTERM to pid 0 (bnc#589064)
* Thu Apr 15 2010 hare@suse.de
- Set correct 'interface' variable for mkinitrd (bnc#596627)
* Tue Apr 13 2010 hare@suse.de
- Remove ibft mkinitrd scripts.
* Mon Apr 12 2010 hare@suse.de
- Only set nettype to 'dhcp' if a valid DHCP address was found
  (bnc#576601)
- Do not print 'umounting failed' on shutdown (bnc#581259)
* Fri Mar 26 2010 hare@suse.de
- Do no umount root fs on shutdown (bnc#581259)
* Thu Mar 25 2010 hare@suse.de
- Update brcm_uio daemon to version 0.5.7 (bnc#576601)
- Load transport modules if configured (bnc#590531)
* Fri Mar 12 2010 mmarek@suse.cz
- Do not hardcode the iscsi_ibft module in the iscsi mkinitrd
  script, the ibft script handles this correctly (bnc#528657).
* Fri Mar 12 2010 hare@suse.de
- Don't close sessions if umount fails (bnc#581259)
* Mon Feb 22 2010 hare@suse.de
- Start brcm_uio daemon conditionally if HW is present (bnc#576601)
* Mon Feb 15 2010 mmarek@suse.de
- Include <sys/types.h> for pid_t.
* Mon Feb  8 2010 hare@suse.de
- Add brcm_uio daemon for bnx2i iSCSI offload (bnc#576601)
* Thu Dec 17 2009 hare@suse.de
- Do not modify network parameter when iBFT is not found
  (bnc#562030)
- Use correct value for iBFT 'origin' parameter (bnc#565116)
* Thu Dec 10 2009 hare@suse.de
- iscsiadm fails to read ibft (bnc#561596)
* Wed Nov 18 2009 hare@suse.de
- Update to 2.0-871 (FATE#307216)
- Renumber patches
- Add mkinitrd scriptlet for iBFT setup (bnc#541892)
- Fall back to kernel name in mkinitrd setup if udev fails
- Allow empty usernames for CHAP
- Read initiatorname correctly from sysfs (bnc#541882)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Aug 19 2009 hare@suse.de
- Synchronize startup settings (bnc#514273)
- Fix daemon segfault with CHAP (bnc#519402)
- Do not use temp file in iscsi_discovery (bnc#528711)
* Sun Jun 21 2009 crrodriguez@suse.de
- build with fno-strict-aliasing
- do not use static libc, this does not work in reality, use
  of getaddrinfo(3) requires shared libraries at runtime
* Tue Feb 10 2009 hare@suse.de
- search_ibft() might crash when no iBFT is found (bnc#471475)
* Mon Jan 26 2009 ro@suse.de
- change fillup call from "-Y" to "-y" the boot script has
  been present in this package for long enough (SLES10-GA)
* Thu Jan 22 2009 hare@suse.de
- Fix relogin retry handling (bnc#466846)
* Mon Dec  8 2008 hare@suse.de
- Remove trailing tilde from /etc/iscsi/ifaces.example (bnc#450870)
* Fri Dec  5 2008 hare@suse.de
- Fixup 'onboot' for loginall (bnc#449108)
- Remove unused 'dump_char' definition in log.c
- Load ibft module before reading /sys/firmware (bnc#450897)
* Tue Dec  2 2008 hare@suse.de
- iscsiadm -m fw crashes on ppc (bnc#449116)
* Thu Nov 20 2008 hare@suse.de
- Add cxgb3i support (bnc#433500, FATE#304154)
- No pid file from init scripts
* Thu Nov 13 2008 hare@suse.de
- Update iscsi-gen-initiatorname to work with newer kernels
  (bnc#443509)
* Wed Nov 12 2008 hare@suse.de
- Update SUSE init scripts to work with newer kernels
- Move mkinitrd scriptlets to git repository
- Fixes for root-on-iSCSI:
  * Update mkinitrd scripts to work with newer kernels (bnc#435215)
  * Allow 'onboot' for iscsiadm -L
  * Add option to not write a pid file
- Update login retry mechanism to work around the spanning-tree
  issue (bnc#433363)
* Wed Sep  3 2008 hare@suse.de
- Pull in fixes from upstream git repository
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Thu Jul 24 2008 hare@suse.de
- Update to 2.0-870-rc1
  * Fix login redirection
  * Fix NOP timeout handling
  * Various small bugfixes
- Include mkinitrd scriptlets.
* Tue Apr 29 2008 hare@suse.de
- Pull in fixes from upstream git repository
* Mon Apr 21 2008 hare@suse.de
- Scan memory area for iBFT correctly (bnc#378837)
* Tue Apr 15 2008 hare@suse.de
- Synchronize with SLES10 SP2
* Thu Apr 10 2008 hare@suse.de
- Tear down device stack before logging out (bnc#378141)
* Fri Apr  4 2008 hare@suse.de
- Don't try to print invalid log messages (bnc#372719)
- Cleanup IPC identifiers upon error (bnc#372719)
- Print iBFT error messages to stderr (bnc#372725)
* Mon Mar 17 2008 hare@suse.de
- Don't fail init script if called twice with 'stop' (bnc#369300)
* Wed Mar 12 2008 hare@suse.de
- Add parameter '-i' to fwparam_ibft for mkinitrd (bnc#277106)
- Only logout from targets marked as 'automatic' (bnc#369767)
* Mon Mar 10 2008 hare@suse.de
- Synchronize with git repository
- Fixes to simplify build process
- Re-implement fwparam_ibft (bnc#367437)
* Wed Mar  5 2008 hare@suse.de
- Fixup '-op' to not overwrite other nodes on discovery
  (bnc#365259)
* Mon Feb 18 2008 hare@suse.de
- Fixup /etc/init.d/boot.open-iscsi to use correct syntax
  for iscsiadm (bnc#360674)
* Thu Feb  7 2008 hare@suse.de
- Add '-op' option to discovery to avoid overwriting
  of existing nodes (bnc#357197)
* Thu Dec  6 2007 hare@suse.de
- Update to official version 2.0-866
- Include latest git patches (FATE#303021)
- Start initiator after iSCSI target (FATE#302415)
* Fri Nov 30 2007 hare@suse.de
- Rediscover all targets to make sure the network
  is up (#307930, #251675)
- Fixup debug option to iscsiadm (#346504)
* Thu Nov 15 2007 hare@suse.de
- Do not overwrite existing node records when doing a
  discovery (#278172)
* Fri Oct 26 2007 bphilips@suse.de
- Scan BIOS memory in blocks to avoid crash on buggy
  BIOS (#293845)
- Don't unload modules on stop to avoid kernel oops (#328923)
* Thu Aug  2 2007 hare@suse.de
- Fix insecure privileges and credential verification (#280413)
* Mon Jul  9 2007 hare@suse.de
- update to svn r866
- include latest git patches
* Fri May 11 2007 hare@suse.de
- Correct target and initiator mixup for ppc (#273600)
- Print LUN correctly (#271292)
* Thu Apr 26 2007 hare@suse.de
- fwparam_ibft crashes with Broadcom chips (#267458)
* Wed Apr  4 2007 hare@suse.de
- update to official release 2.0-754
- update to svn r779
- Include changes from SLES10 SP1
* Fri Mar 30 2007 hare@suse.de
- Include fwparam_ibft program for OpenPROM (#226682)
* Wed Mar 28 2007 hare@suse.de
- Return status '6' when root on iSCSI is not enabled (#257979)
* Fri Mar 16 2007 hare@suse.de
- Fix typo in output of fwparam_ibft (#250445)
* Thu Mar  8 2007 hare@suse.de
- connect() to the daemon might fail on busy machines (#244649)
* Mon Mar  5 2007 hare@suse.de
- Add /usr/bin/iscsi-dbconvert to convert SLES10 GA
  databases to new format (#251298)
* Fri Feb 16 2007 hare@suse.de
- Fix iscsiadm to print session info correctly (#243203)
* Thu Feb  8 2007 hare@suse.de
- update to svn r768
  - Update iSNS support (#243203)
- Correct typo in /etc/init.d/boot.open-iscsi (#243203)
* Fri Feb  2 2007 hare@suse.de
- Umount all luns on shutdown (#223484)
* Wed Jan 31 2007 hare@suse.de
- Remove the start iSCSI after Xen hack (#231077)
- Fixup /etc/init.d/boot.open-iscsi script (#239819)
* Thu Jan 18 2007 hare@suse.de
- Fix compat mode to display the record id.
- Add /sbin/iscsi-gen-initiatorname to generate
  a default iSCSI initiatorname.
* Mon Jan 15 2007 hare@suse.de
-  Fixup %%post scripts.
* Mon Jan 15 2007 hare@suse.de
- Reference symlink to /etc/iscsid.conf in rpm.
* Fri Jan 12 2007 hare@suse.de
- update to official version 2.0-707
- update to svn r759
  - Include iBFT BIOS tool (FATE 301671)
- Implement compability mode for iscsiadm
* Fri Oct 20 2006 hare@suse.de
- Update to svn r713
- Use /dev/urandom instead of rand() (#180837)
- Fixup init script
* Fri Oct  6 2006 hare@suse.de
- Update to official version 2.0-707
* Fri Jul 28 2006 olh@suse.de
- remove unused boot.proc from boot.open-iscsi (#181972)
* Mon Jun 19 2006 hare@suse.de
- update to svn r606
  - Include local patches
  - Fix OCFS2 hangs (#185107, #180773)
* Thu Jun  1 2006 hare@suse.de
- Added new startmode 'onboot' for root on iSCSI
- Added new init script boot.open-iscsi startup
  iscsid as early as possible (#176804)
* Wed May 31 2006 hare@suse.de
- update to svn r595
  - Include local patches
  - Fix lockup on target restart for real (#176151)
* Mon May 22 2006 hare@suse.de
- update to svn r581
  - Fix lockup when target is restarted (#176151)
- Start open-iscsi after Xen (#177381)
* Fri May 19 2006 hare@suse.de
- update to svn r574
  - Fix machine hang during error recovery (#174166)
- Display chap secrets for yast (#149055)
* Tue May  2 2006 hare@suse.de
- update to svn r564
  (contains all local changes)
* Tue Apr 25 2006 wrwhitehead@novell.com
- Fix communication hang (#157463).
- The iscsi-tcp_data_ready callback needs to empty out the
  tcp receive queue rather than just rely on the callback to
  occur for every message in the receive queue.
* Fri Apr 21 2006 hare@suse.de
- update to svn r545
  Fixes a crash with Wasabi targets (#157463).
* Wed Mar 22 2006 hare@suse.de
- Add rcopen-iscsi link (#158230)
- Check for active records before deletion (#149935)
- Do not display error messages on startup if no
  records are found.
* Fri Mar 10 2006 hare@suse.de
- Update to svn r520 (contains all local changes)
- Add documentation for discovery types (#149936)
* Tue Feb 28 2006 hare@suse.de
- Fixed type of portal_group_tag (#153638)
* Tue Feb 21 2006 hare@suse.de
- Fixed open-iscsi startup script (#148982)
* Mon Feb 20 2006 hare@suse.de
- Update to svn r495
- Implement iSCSI boot support (FATE #140350)
* Thu Feb  9 2006 hare@suse.de
- Update to svn r488 to match kernel revision
  (#149412).
- Remove obsolete patches.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 hare@suse.de
- Update to svn r473
- Enhance start script
- Fix appearent login failures.
* Fri Jan 20 2006 hare@suse.de
- Update to svn r471
- Fix start script.
* Mon Jan 16 2006 hare@suse.de
- Add Provides/Obsoletes tag.
* Fri Jan 13 2006 hare@suse.de
- Rebasing package to open-iscsi-0.5-454
- Update to svn r457
* Mon Dec 19 2005 hare@suse.de
- Update to svn r446.
* Thu Nov  3 2005 hare@suse.de
- Update to svn r436.
* Thu Sep  8 2005 hare@suse.de
- Update to svn r408.
  (Added NOOP IN handling)
- Removed obsolete patches
* Mon Aug 22 2005 hare@suse.de
- Update to svn r401.
- Fixed package to install properly.
- Fixed init script
- Added iscsi-iname to generate iSCSI Initiatorname.
* Mon Aug  8 2005 hare@suse.de
- Update to svn r389.
* Thu Jul  7 2005 hare@suse.de
- Initial version 0.3rc6-369
